pub fn run_calculations(tree: &mut FieldTree, handler: &mut dyn JsActionHandler)Expand description
Run calculation scripts for all fields in the calculation order (/CO).
pub fn run_calculations(tree: &mut FieldTree, handler: &mut dyn JsActionHandler)Run calculation scripts for all fields in the calculation order (/CO).