pub trait DocumentOps {
// Required methods
fn page_count(&self) -> usize;
fn form(&self) -> Option<&dyn FormAccess>;
fn form_mut(&mut self) -> Option<&mut dyn FormAccess>;
}Expand description
Unified document operations.
Provides access to form data, page count, and other document-level operations through a single interface.
Required Methods
Sourcefn page_count(&self) -> usize
fn page_count(&self) -> usize
Returns the number of pages in the document.
Sourcefn form(&self) -> Option<&dyn FormAccess>
fn form(&self) -> Option<&dyn FormAccess>
Returns read-only access to the form engine, if any.
Sourcefn form_mut(&mut self) -> Option<&mut dyn FormAccess>
fn form_mut(&mut self) -> Option<&mut dyn FormAccess>
Returns mutable access to the form engine, if any.