Module text

Module text 

Text field implementation (B.2).

Enums

TextFieldKind
Sub-kind of a text (/Tx) field, derived from its flags word.

Functions

comb_cell_width
For comb fields, compute the width of each cell.
get_text_value
Get the current text value of a text field.
set_text_value
Set a text field’s value, enforcing MaxLen if present. Returns false if the field is read-only.
text_field_kind
Determine the text field sub-kind from field flags.