Text field implementation (B.2).
Enums
- Text
Field Kind - Sub-kind of a text (
/Tx) field, derived from its flags word.
Functions
- comb_
cell_ width - For comb fields, compute the width of each cell.
- get_
text_ value - Get the current text value of a text field.
- set_
text_ value - Set a text field’s value, enforcing MaxLen if present.
Returns
falseif the field is read-only. - text_
field_ kind - Determine the text field sub-kind from field flags.